Skip to contents

Get LEHD Origin-Destination Employment Statistics (LODES) data

Usage

get_lodes(
  lodes_type,
  jobs_type = "all",
  states,
  years,
  geography = "tract",
  state_part = "main"
)

Arguments

lodes_type

One of c("rac", "wac", "od"). "rac" = Residence Area Characteristics, where jobs are associated with employees' residences. "wac" = Workplace Area Characteristics, where jobs are associated with employees' workplaces. "od" = Origin-Destination data, where jobs are associated with both workers' residences and their workplaces.

jobs_type

One of c("all", "primary"). Default is "all", which includes multiple jobs for workers with multiple jobs. "primary" includes only the highest-paying job per worker.

states

A vector of state abbreviations.

years

A vector of years.

geography

One of c("block", "block group", "tract", "county", "state"). Default is "tract".

state_part

One of c("main", "aux"). Default is "main", which includes only workers who reside inside the state where they work. "aux" returns only workers who work in the specified state but live outside of that state.

Value

A tibble with one record per geography per year per job type. Attributes include total jobs and jobs by worker earnings, industry, and demographics; the origin-destination results have more limited demographics compared to the "wac" and "rac" results.

year

the year for which LODES data is pulled from

state

A two-digit state identifier.

GEOID

11 digit identifier denoted as either h_GEOID representing the employees' residence census block code or w_GEOID representing the employees' workplace census block code

job_type

one of either 'all' jobs or only 'federal' jobs

total_jobs

total number of jobs in a given tract

jobs_workers_age

number of employees by given age range

jobs_earnings

number of employees by given monthly earnings range

jobs_industry

number of employees by given industry

jobs_workers_race

number of employees by given race, inclusive of hispanic or latino; only available in 'wac' and 'rac' datasets

jobs_workers_ethnicity

number of employess by hispanic or latino status, regardless of race; only available in 'wac' and 'rac' datasets

jobs_workers_educational_attainment

number of employees by highest level of education attained; only available in 'wac' and 'rac' datasets

jobs_workers_sex

number of employees by sex; only available in 'wac' and 'rac' datasets

jobs_firm_age

number of employees by the age of employing firm; only available in 'wac' datasets

jobs_firm_size

number of employees for a given range in employer size; only available in 'wac' datasets

Details

The Longitudinal Employer-Household Dynamics (LEHD) data at the U.S. Census Bureau is a quarterly database of linked employer-employee data covering over 95% of employment in the United States. The LEHD data are generated by merging previously collected survey and administrative data on jobs, businesses, and workers.

LEHD Origin-Destination Employment Statistics (LODES)is a partially synthetic dataset that describes geographic patterns of jobs by their employment locations and residential locations as well as the connections between the two locations. The microdata link employee and employer data by combining administrative state unemployment insurance wage records with other administrative and survey data. The source data are aggregated and adjusted to protect confidentiality.

LODES data includes three datasets: Residence Area Characteristics (RAC): This file lists the total number of jobs by the census block where the employee lives.

Workplace Area Characteristics (WAC): This file lists the total number of jobs by the census block where the employee works.

Origin-Destination (OD): This file lists job totals by both the census block where the employee lives and the census block where the employee works

While similar to County Business Patterns (CBP) data in it's coverage of employment statistics, LODES differs mainly due to its more granular geographies (tract vs. county) and focus on framing the statistics at the individual/job level found in LODES data.